Class: Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest::GoogleOAuthParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/developerconnect/v1/developer_connect.rb

Overview

The params returned by Google OAuth flow redirects.

Instance Attribute Summary collapse

Instance Attribute Details

#scopes::Array<::String>

Returns Required. The scopes returned by Google OAuth flow.

Returns:

  • (::Array<::String>)

    Required. The scopes returned by Google OAuth flow.



1070
1071
1072
1073
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1070

class GoogleOAuthParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ticket::String

Returns Required. The ticket to be used for post processing the callback from Google OAuth flow.

Returns:

  • (::String)

    Required. The ticket to be used for post processing the callback from Google OAuth flow.



1070
1071
1072
1073
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1070

class GoogleOAuthParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version_info::String

Returns Optional. The version info returned by Google OAuth flow.

Returns:

  • (::String)

    Optional. The version info returned by Google OAuth flow.



1070
1071
1072
1073
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1070

class GoogleOAuthParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end