Class: Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest::OAuthParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/developerconnect/v1/developer_connect.rb

Overview

The params returned by non-Google OAuth 2.0 flow redirect.

Instance Attribute Summary collapse

Instance Attribute Details

#code::String

Returns Required. The code to be used for getting the token from SCM provider.

Returns:

  • (::String)

    Required. The code to be used for getting the token from SCM provider.



1054
1055
1056
1057
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1054

class OAuthParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ticket::String

Returns Required. The ticket to be used for post processing the callback from SCM provider.

Returns:

  • (::String)

    Required. The ticket to be used for post processing the callback from SCM provider.



1054
1055
1056
1057
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1054

class OAuthParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end