Class: Google::Cloud::DeveloperConnect::V1::GitHubConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DeveloperConnect::V1::GitHubConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/developer_connect.rb
Overview
Configuration for connections to github.com.
Defined Under Namespace
Modules: GitHubApp
Instance Attribute Summary collapse
-
#app_installation_id ⇒ ::Integer
Optional.
-
#authorizer_credential ⇒ ::Google::Cloud::DeveloperConnect::V1::OAuthCredential
Optional.
-
#github_app ⇒ ::Google::Cloud::DeveloperConnect::V1::GitHubConfig::GitHubApp
Required.
-
#installation_uri ⇒ ::String
readonly
Output only.
Instance Attribute Details
#app_installation_id ⇒ ::Integer
Returns Optional. GitHub App installation id.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 309 class GitHubConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various GitHub Applications that can be installed to a # GitHub user or organization and used with Developer Connect. module GitHubApp # GitHub App not specified. GIT_HUB_APP_UNSPECIFIED = 0 # The Developer Connect GitHub Application. DEVELOPER_CONNECT = 1 # The Firebase GitHub Application. FIREBASE = 2 # The Gemini Code Assist Application. GEMINI_CODE_ASSIST = 3 end end |
#authorizer_credential ⇒ ::Google::Cloud::DeveloperConnect::V1::OAuthCredential
Returns Optional. OAuth credential of the account that authorized the GitHub App. It is recommended to use a robot account instead of a human user account. The OAuth token must be tied to the GitHub App of this config.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 309 class GitHubConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various GitHub Applications that can be installed to a # GitHub user or organization and used with Developer Connect. module GitHubApp # GitHub App not specified. GIT_HUB_APP_UNSPECIFIED = 0 # The Developer Connect GitHub Application. DEVELOPER_CONNECT = 1 # The Firebase GitHub Application. FIREBASE = 2 # The Gemini Code Assist Application. GEMINI_CODE_ASSIST = 3 end end |
#github_app ⇒ ::Google::Cloud::DeveloperConnect::V1::GitHubConfig::GitHubApp
Returns Required. Immutable. The GitHub Application that was installed to the GitHub user or organization.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 309 class GitHubConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various GitHub Applications that can be installed to a # GitHub user or organization and used with Developer Connect. module GitHubApp # GitHub App not specified. GIT_HUB_APP_UNSPECIFIED = 0 # The Developer Connect GitHub Application. DEVELOPER_CONNECT = 1 # The Firebase GitHub Application. FIREBASE = 2 # The Gemini Code Assist Application. GEMINI_CODE_ASSIST = 3 end end |
#installation_uri ⇒ ::String (readonly)
Returns Output only. The URI to navigate to in order to manage the installation associated with this GitHubConfig.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 309 class GitHubConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the various GitHub Applications that can be installed to a # GitHub user or organization and used with Developer Connect. module GitHubApp # GitHub App not specified. GIT_HUB_APP_UNSPECIFIED = 0 # The Developer Connect GitHub Application. DEVELOPER_CONNECT = 1 # The Firebase GitHub Application. FIREBASE = 2 # The Gemini Code Assist Application. GEMINI_CODE_ASSIST = 3 end end |