Class: Google::Cloud::DeveloperConnect::V1::GitProxyConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/developerconnect/v1/developer_connect.rb

Overview

The git proxy configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#enabled::Boolean

Returns Optional. Setting this to true allows the git proxy to be used for performing git operations on the repositories linked in the connection.

Returns:

  • (::Boolean)

    Optional. Setting this to true allows the git proxy to be used for performing git operations on the repositories linked in the connection.



198
199
200
201
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 198

class GitProxyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#http_proxy_base_uri::String (readonly)

Returns Output only. The base URI for the HTTP proxy endpoint. Has the format https://{generatedID}-c-h-{shortRegion}.developerconnect.dev Populated only when enabled is set to true. This endpoint is used by other Google services that integrate with Developer Connect.

Returns:

  • (::String)

    Output only. The base URI for the HTTP proxy endpoint. Has the format https://{generatedID}-c-h-{shortRegion}.developerconnect.dev Populated only when enabled is set to true. This endpoint is used by other Google services that integrate with Developer Connect.



198
199
200
201
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 198

class GitProxyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end