Class: Google::Cloud::DeveloperConnect::V1::StartOAuthResponse
- Inherits:
-
Object
- Object
- Google::Cloud::DeveloperConnect::V1::StartOAuthResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/developer_connect.rb
Overview
Message for responding to starting an OAuth flow.
Instance Attribute Summary collapse
-
#auth_uri ⇒ ::String
The authorization server URL to the OAuth flow of the service provider.
-
#client_id ⇒ ::String
The client ID to the OAuth App of the service provider.
-
#code_challenge ⇒ ::String
Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.1.
-
#code_challenge_method ⇒ ::String
Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.2.
-
#scopes ⇒ ::Array<::String>
The list of scopes requested by the application.
-
#system_provider_id ⇒ ::Google::Cloud::DeveloperConnect::V1::SystemProvider
The ID of the system provider.
-
#ticket ⇒ ::String
The ticket to be used for post processing the callback from the service provider.
Instance Attribute Details
#auth_uri ⇒ ::String
Returns The authorization server URL to the OAuth flow of the service provider.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_id ⇒ ::String
Returns The client ID to the OAuth App of the service provider.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#code_challenge ⇒ ::String
Returns Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.1.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#code_challenge_method ⇒ ::String
Returns Please refer to https://datatracker.ietf.org/doc/html/rfc7636#section-4.2.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scopes ⇒ ::Array<::String>
Returns The list of scopes requested by the application.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#system_provider_id ⇒ ::Google::Cloud::DeveloperConnect::V1::SystemProvider
Returns The ID of the system provider.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ticket ⇒ ::String
Returns The ticket to be used for post processing the callback from the service provider.
1022 1023 1024 1025 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1022 class StartOAuthResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |