Class: Google::Cloud::Developerconnect::V1::GoogleArtifactAnalysis

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/developerconnect/v1/insights_config.rb

Overview

Google Artifact Analysis configurations.

Instance Attribute Summary collapse

Instance Attribute Details

#project_id::String

Returns Required. The project id of the project where the provenance is stored.

Returns:

  • (::String)

    Required. The project id of the project where the provenance is stored.



260
261
262
263
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 260

class GoogleArtifactAnalysis
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end