Class: Google::Cloud::Developerconnect::V1::ListDeploymentEventsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Developerconnect::V1::ListDeploymentEventsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/insights_config.rb
Overview
Response to listing DeploymentEvents.
Instance Attribute Summary collapse
-
#deployment_events ⇒ ::Array<::Google::Cloud::Developerconnect::V1::DeploymentEvent>
The list of DeploymentEvents.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#deployment_events ⇒ ::Array<::Google::Cloud::Developerconnect::V1::DeploymentEvent>
Returns The list of DeploymentEvents.
383 384 385 386 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 383 class ListDeploymentEventsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
383 384 385 386 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 383 class ListDeploymentEventsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |