Class: Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/developer_connect.rb
Overview
Message for finishing an OAuth flow.
Defined Under Namespace
Classes: GoogleOAuthParams, OAuthParams
Instance Attribute Summary collapse
-
#account_connector ⇒ ::String
Required.
-
#google_oauth_params ⇒ ::Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest::GoogleOAuthParams
The params returned by Google OAuth flow redirects.
-
#oauth_params ⇒ ::Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest::OAuthParams
The params returned by non-Google OAuth 2.0 flow redirect.
Instance Attribute Details
#account_connector ⇒ ::String
Returns Required. The resource name of the AccountConnector in the format
projects/*/locations/*/accountConnectors/*.
1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1042 class FinishOAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The params returned by non-Google OAuth 2.0 flow redirect. # @!attribute [rw] code # @return [::String] # Required. The code to be used for getting the token from SCM provider. # @!attribute [rw] ticket # @return [::String] # Required. The ticket to be used for post processing the callback from SCM # provider. class OAuthParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The params returned by Google OAuth flow redirects. # @!attribute [rw] scopes # @return [::Array<::String>] # Required. The scopes returned by Google OAuth flow. # @!attribute [rw] version_info # @return [::String] # Optional. The version info returned by Google OAuth flow. # @!attribute [rw] ticket # @return [::String] # Required. The ticket to be used for post processing the callback from # Google OAuth flow. class GoogleOAuthParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#google_oauth_params ⇒ ::Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest::GoogleOAuthParams
Returns The params returned by Google OAuth flow redirects.
Note: The following fields are mutually exclusive: google_oauth_params, oauth_params. If a field in that set is populated, all other fields in the set will automatically be cleared.
1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1042 class FinishOAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The params returned by non-Google OAuth 2.0 flow redirect. # @!attribute [rw] code # @return [::String] # Required. The code to be used for getting the token from SCM provider. # @!attribute [rw] ticket # @return [::String] # Required. The ticket to be used for post processing the callback from SCM # provider. class OAuthParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The params returned by Google OAuth flow redirects. # @!attribute [rw] scopes # @return [::Array<::String>] # Required. The scopes returned by Google OAuth flow. # @!attribute [rw] version_info # @return [::String] # Optional. The version info returned by Google OAuth flow. # @!attribute [rw] ticket # @return [::String] # Required. The ticket to be used for post processing the callback from # Google OAuth flow. class GoogleOAuthParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#oauth_params ⇒ ::Google::Cloud::DeveloperConnect::V1::FinishOAuthRequest::OAuthParams
Returns The params returned by non-Google OAuth 2.0 flow redirect.
Note: The following fields are mutually exclusive: oauth_params, google_oauth_params. If a field in that set is populated, all other fields in the set will automatically be cleared.
1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 1042 class FinishOAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The params returned by non-Google OAuth 2.0 flow redirect. # @!attribute [rw] code # @return [::String] # Required. The code to be used for getting the token from SCM provider. # @!attribute [rw] ticket # @return [::String] # Required. The ticket to be used for post processing the callback from SCM # provider. class OAuthParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The params returned by Google OAuth flow redirects. # @!attribute [rw] scopes # @return [::Array<::String>] # Required. The scopes returned by Google OAuth flow. # @!attribute [rw] version_info # @return [::String] # Optional. The version info returned by Google OAuth flow. # @!attribute [rw] ticket # @return [::String] # Required. The ticket to be used for post processing the callback from # Google OAuth flow. class GoogleOAuthParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |