Class: Google::Cloud::DeveloperConnect::V1::GenericHTTPEndpointConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DeveloperConnect::V1::GenericHTTPEndpointConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/developer_connect.rb
Overview
Defines the configuration for connections to an HTTP service provider.
Defined Under Namespace
Classes: BasicAuthentication, BearerTokenAuthentication
Instance Attribute Summary collapse
-
#basic_authentication ⇒ ::Google::Cloud::DeveloperConnect::V1::GenericHTTPEndpointConfig::BasicAuthentication
Optional.
-
#bearer_token_authentication ⇒ ::Google::Cloud::DeveloperConnect::V1::GenericHTTPEndpointConfig::BearerTokenAuthentication
Optional.
-
#host_uri ⇒ ::String
Required.
-
#service_directory_config ⇒ ::Google::Cloud::DeveloperConnect::V1::ServiceDirectoryConfig
Optional.
-
#ssl_ca_certificate ⇒ ::String
Optional.
Instance Attribute Details
#basic_authentication ⇒ ::Google::Cloud::DeveloperConnect::V1::GenericHTTPEndpointConfig::BasicAuthentication
Returns Optional. Basic authentication with username and password.
Note: The following fields are mutually exclusive: basic_authentication, bearer_token_authentication. If a field in that set is populated, all other fields in the set will automatically be cleared.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 266 class GenericHTTPEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Basic authentication with username and password. # @!attribute [rw] password_secret_version # @return [::String] # The password SecretManager secret version to authenticate as. # @!attribute [rw] username # @return [::String] # Required. The username to authenticate as. class BasicAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bearer token authentication with a token. # @!attribute [rw] token_secret_version # @return [::String] # Optional. The token SecretManager secret version to authenticate as. class BearerTokenAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#bearer_token_authentication ⇒ ::Google::Cloud::DeveloperConnect::V1::GenericHTTPEndpointConfig::BearerTokenAuthentication
Returns Optional. Bearer token authentication with a token.
Note: The following fields are mutually exclusive: bearer_token_authentication, basic_authentication. If a field in that set is populated, all other fields in the set will automatically be cleared.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 266 class GenericHTTPEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Basic authentication with username and password. # @!attribute [rw] password_secret_version # @return [::String] # The password SecretManager secret version to authenticate as. # @!attribute [rw] username # @return [::String] # Required. The username to authenticate as. class BasicAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bearer token authentication with a token. # @!attribute [rw] token_secret_version # @return [::String] # Optional. The token SecretManager secret version to authenticate as. class BearerTokenAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#host_uri ⇒ ::String
Returns Required. Immutable. The service provider's https endpoint.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 266 class GenericHTTPEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Basic authentication with username and password. # @!attribute [rw] password_secret_version # @return [::String] # The password SecretManager secret version to authenticate as. # @!attribute [rw] username # @return [::String] # Required. The username to authenticate as. class BasicAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bearer token authentication with a token. # @!attribute [rw] token_secret_version # @return [::String] # Optional. The token SecretManager secret version to authenticate as. class BearerTokenAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_directory_config ⇒ ::Google::Cloud::DeveloperConnect::V1::ServiceDirectoryConfig
Returns Optional. Configuration for using Service Directory to privately connect to a HTTP service provider. This should only be set if the Http service provider is hosted on-premises and not reachable by public internet. If this field is left empty, calls to the HTTP service provider will be made over the public internet.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 266 class GenericHTTPEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Basic authentication with username and password. # @!attribute [rw] password_secret_version # @return [::String] # The password SecretManager secret version to authenticate as. # @!attribute [rw] username # @return [::String] # Required. The username to authenticate as. class BasicAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bearer token authentication with a token. # @!attribute [rw] token_secret_version # @return [::String] # Optional. The token SecretManager secret version to authenticate as. class BearerTokenAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ssl_ca_certificate ⇒ ::String
Returns Optional. The SSL certificate to use for requests to the HTTP service provider.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'proto_docs/google/cloud/developerconnect/v1/developer_connect.rb', line 266 class GenericHTTPEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Basic authentication with username and password. # @!attribute [rw] password_secret_version # @return [::String] # The password SecretManager secret version to authenticate as. # @!attribute [rw] username # @return [::String] # Required. The username to authenticate as. class BasicAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bearer token authentication with a token. # @!attribute [rw] token_secret_version # @return [::String] # Optional. The token SecretManager secret version to authenticate as. class BearerTokenAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |