Class: Google::Cloud::Developerconnect::V1::ArtifactDeployment
- Inherits:
-
Object
- Object
- Google::Cloud::Developerconnect::V1::ArtifactDeployment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/insights_config.rb
Overview
The ArtifactDeployment resource represents the deployment of the artifact within the InsightsConfig resource.
Instance Attribute Summary collapse
-
#artifact_alias ⇒ ::String
readonly
Output only.
-
#artifact_reference ⇒ ::String
readonly
Output only.
-
#container_status_summary ⇒ ::String
readonly
Output only.
-
#deploy_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#id ⇒ ::String
readonly
Output only.
-
#source_commit_uris ⇒ ::Array<::String>
readonly
Output only.
-
#undeploy_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#artifact_alias ⇒ ::String (readonly)
Returns Output only. The artifact alias in the deployment spec, with Tag/SHA. e.g. us-docker.pkg.dev/my-project/my-repo/image:1.0.0.
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#artifact_reference ⇒ ::String (readonly)
Returns Output only. The artifact that is deployed.
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#container_status_summary ⇒ ::String (readonly)
Returns Output only. The summary of container status of the artifact deployment.
Format as ContainerStatusState-Reason : restartCount
e.g. "Waiting-ImagePullBackOff : 3".
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deploy_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the deployment was deployed.
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String (readonly)
Returns Output only. Unique identifier of ArtifactDeployment.
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_commit_uris ⇒ ::Array<::String> (readonly)
Returns Output only. The source commits at which this artifact was built. Extracted from provenance.
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#undeploy_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the deployment was undeployed, all artifacts are considered undeployed once this time is set.
416 417 418 419 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 416 class ArtifactDeployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |