Class: Google::Cloud::Developerconnect::V1::DeploymentEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Developerconnect::V1::DeploymentEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/insights_config.rb
Overview
The DeploymentEvent resource represents the deployment of the artifact within the InsightsConfig resource.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#artifact_deployments ⇒ ::Array<::Google::Cloud::Developerconnect::V1::ArtifactDeployment>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#deploy_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#runtime_config ⇒ ::Google::Cloud::Developerconnect::V1::RuntimeConfig
readonly
Output only.
-
#runtime_deployment_uri ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Developerconnect::V1::DeploymentEvent::State
readonly
Output only.
-
#undeploy_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#artifact_deployments ⇒ ::Array<::Google::Cloud::Developerconnect::V1::ArtifactDeployment> (readonly)
Returns Output only. The artifact deployments of the DeploymentEvent. Each artifact deployment contains the artifact uri and the runtime configuration uri. For GKE, this would be all the containers images that are deployed in the pod.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The create time of the DeploymentEvent.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#deploy_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the DeploymentEvent was deployed. This would be the min of all ArtifactDeployment deploy_times.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#name ⇒ ::String
Returns Identifier. The name of the DeploymentEvent. This name is provided by Developer Connect insights. Format: projects/{project}/locations/{location}/insightsConfigs/{insights_config}/deploymentEvents/{uuid}.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#runtime_config ⇒ ::Google::Cloud::Developerconnect::V1::RuntimeConfig (readonly)
Returns Output only. The runtime configurations where the DeploymentEvent happened.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#runtime_deployment_uri ⇒ ::String (readonly)
Returns Output only. The runtime assigned URI of the DeploymentEvent. For GKE, this is the fully qualified replica set uri. e.g. container.googleapis.com/projects/{project}/locations/{location}/clusters/{cluster}/k8s/namespaces/{namespace}/apps/replicasets/{replica-set-id} For Cloud Run, this is the revision name.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#state ⇒ ::Google::Cloud::Developerconnect::V1::DeploymentEvent::State (readonly)
Returns Output only. The state of the DeploymentEvent.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#undeploy_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the DeploymentEvent was undeployed, all artifacts are considered undeployed once this time is set. This would be the max of all ArtifactDeployment undeploy_times. If any ArtifactDeployment is still active (i.e. does not have an undeploy_time), this field will be empty.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The update time of the DeploymentEvent.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 319 class DeploymentEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the DeploymentEvent. module State # No state specified. STATE_UNSPECIFIED = 0 # The deployment is active in the runtime. STATE_ACTIVE = 1 # The deployment is not in the runtime. STATE_INACTIVE = 2 end end |