Class: Google::Cloud::Developerconnect::V1::InsightsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Developerconnect::V1::InsightsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/insights_config.rb
Overview
The InsightsConfig resource is the core configuration object to capture events from your Software Development Lifecycle. It acts as the central hub for managing how Developer Connect understands your application, its runtime environments, and the artifacts deployed within them.
Defined Under Namespace
Modules: State Classes: AnnotationsEntry, LabelsEntry
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#app_hub_application ⇒ ::String
Optional.
-
#artifact_configs ⇒ ::Array<::Google::Cloud::Developerconnect::V1::ArtifactConfig>
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#errors ⇒ ::Array<::Google::Rpc::Status>
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#projects ⇒ ::Google::Cloud::Developerconnect::V1::Projects
Optional.
-
#reconciling ⇒ ::Boolean
readonly
Output only.
-
#runtime_configs ⇒ ::Array<::Google::Cloud::Developerconnect::V1::RuntimeConfig>
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Developerconnect::V1::InsightsConfig::State
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. User specified annotations. See https://google.aip.dev/148#annotations for more details such as format and size limitations.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#app_hub_application ⇒ ::String
Returns Optional. The name of the App Hub Application. Format: projects/{project}/locations/{location}/applications/{application}
Note: The following fields are mutually exclusive: app_hub_application, projects. If a field in that set is populated, all other fields in the set will automatically be cleared.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#artifact_configs ⇒ ::Array<::Google::Cloud::Developerconnect::V1::ArtifactConfig>
Returns Optional. The artifact configurations of the artifacts that are deployed.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create timestamp.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#errors ⇒ ::Array<::Google::Rpc::Status> (readonly)
Returns Output only. Any errors that occurred while setting up the InsightsConfig.
Each error will be in the format: field_name: error_message, e.g.
GetAppHubApplication: Permission denied while getting App Hub
application. Please grant permissions to the P4SA.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Set of labels associated with an InsightsConfig.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#name ⇒ ::String
Returns Identifier. The name of the InsightsConfig. Format: projects/{project}/locations/{location}/insightsConfigs/{insightsConfig}.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#projects ⇒ ::Google::Cloud::Developerconnect::V1::Projects
Returns Optional. The projects to track with the InsightsConfig.
Note: The following fields are mutually exclusive: projects, app_hub_application. If a field in that set is populated, all other fields in the set will automatically be cleared.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#reconciling ⇒ ::Boolean (readonly)
Returns Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to true if the current state of InsightsConfig does not match the user's intended state, and the service is actively updating the resource to reconcile them. This can happen due to user-triggered updates or system actions like failover or maintenance.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#runtime_configs ⇒ ::Array<::Google::Cloud::Developerconnect::V1::RuntimeConfig> (readonly)
Returns Output only. The runtime configurations where the application is deployed.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#state ⇒ ::Google::Cloud::Developerconnect::V1::InsightsConfig::State
Returns Optional. Output only. The state of the InsightsConfig.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Update timestamp.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 81 class InsightsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state of the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The InsightsConfig is pending application discovery/runtime discovery. PENDING = 5 # The initial discovery process is complete. COMPLETE = 3 # The InsightsConfig is in an error state. ERROR = 4 end end |