Class: Google::Cloud::Developerconnect::V1::ListDeploymentEventsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Developerconnect::V1::ListDeploymentEventsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/insights_config.rb
Overview
Request for requesting list of DeploymentEvents.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter expression that matches a subset of the DeploymentEvents. https://google.aip.dev/160.
370 371 372 373 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 370 class ListDeploymentEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of deployment events to return. The service may return fewer than this value. If unspecified, at most 50 deployment events will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
370 371 372 373 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 370 class ListDeploymentEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListDeploymentEvents
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListDeploymentEvents
must match the call that provided the page token.
370 371 372 373 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 370 class ListDeploymentEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent insights config that owns this collection of deployment events. Format: projects/{project}/locations/{location}/insightsConfigs/{insights_config}.
370 371 372 373 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 370 class ListDeploymentEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |