Class: Google::Cloud::Developerconnect::V1::RuntimeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Developerconnect::V1::RuntimeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/developerconnect/v1/insights_config.rb
Overview
RuntimeConfig represents the runtimes where the application is deployed.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#app_hub_service ⇒ ::Google::Cloud::Developerconnect::V1::AppHubService
readonly
Output only.
-
#app_hub_workload ⇒ ::Google::Cloud::Developerconnect::V1::AppHubWorkload
readonly
Output only.
-
#gke_workload ⇒ ::Google::Cloud::Developerconnect::V1::GKEWorkload
readonly
Output only.
-
#google_cloud_run ⇒ ::Google::Cloud::Developerconnect::V1::GoogleCloudRun
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Developerconnect::V1::RuntimeConfig::State
readonly
Output only.
-
#uri ⇒ ::String
Required.
Instance Attribute Details
#app_hub_service ⇒ ::Google::Cloud::Developerconnect::V1::AppHubService (readonly)
Returns Output only. App Hub Service.
Note: The following fields are mutually exclusive: app_hub_service, app_hub_workload. If a field in that set is populated, all other fields in the set will automatically be cleared.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159 class RuntimeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the runtime in the InsightsConfig. # Whether the runtime is linked to the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The runtime configuration has been linked to the InsightsConfig. LINKED = 1 # The runtime configuration has been unlinked to the InsightsConfig. UNLINKED = 2 end end |
#app_hub_workload ⇒ ::Google::Cloud::Developerconnect::V1::AppHubWorkload (readonly)
Returns Output only. App Hub Workload.
Note: The following fields are mutually exclusive: app_hub_workload, app_hub_service. If a field in that set is populated, all other fields in the set will automatically be cleared.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159 class RuntimeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the runtime in the InsightsConfig. # Whether the runtime is linked to the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The runtime configuration has been linked to the InsightsConfig. LINKED = 1 # The runtime configuration has been unlinked to the InsightsConfig. UNLINKED = 2 end end |
#gke_workload ⇒ ::Google::Cloud::Developerconnect::V1::GKEWorkload (readonly)
Returns Output only. Google Kubernetes Engine runtime.
Note: The following fields are mutually exclusive: gke_workload, google_cloud_run. If a field in that set is populated, all other fields in the set will automatically be cleared.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159 class RuntimeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the runtime in the InsightsConfig. # Whether the runtime is linked to the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The runtime configuration has been linked to the InsightsConfig. LINKED = 1 # The runtime configuration has been unlinked to the InsightsConfig. UNLINKED = 2 end end |
#google_cloud_run ⇒ ::Google::Cloud::Developerconnect::V1::GoogleCloudRun (readonly)
Returns Output only. Cloud Run runtime.
Note: The following fields are mutually exclusive: google_cloud_run, gke_workload. If a field in that set is populated, all other fields in the set will automatically be cleared.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159 class RuntimeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the runtime in the InsightsConfig. # Whether the runtime is linked to the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The runtime configuration has been linked to the InsightsConfig. LINKED = 1 # The runtime configuration has been unlinked to the InsightsConfig. UNLINKED = 2 end end |
#state ⇒ ::Google::Cloud::Developerconnect::V1::RuntimeConfig::State (readonly)
Returns Output only. The state of the Runtime.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159 class RuntimeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the runtime in the InsightsConfig. # Whether the runtime is linked to the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The runtime configuration has been linked to the InsightsConfig. LINKED = 1 # The runtime configuration has been unlinked to the InsightsConfig. UNLINKED = 2 end end |
#uri ⇒ ::String
Returns Required. Immutable. The URI of the runtime configuration. For GKE, this is the cluster name. For Cloud Run, this is the service name.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159 class RuntimeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of the runtime in the InsightsConfig. # Whether the runtime is linked to the InsightsConfig. module State # No state specified. STATE_UNSPECIFIED = 0 # The runtime configuration has been linked to the InsightsConfig. LINKED = 1 # The runtime configuration has been unlinked to the InsightsConfig. UNLINKED = 2 end end |