Class: Google::Cloud::Developerconnect::V1::RuntimeConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/developerconnect/v1/insights_config.rb

Overview

RuntimeConfig represents the runtimes where the application is deployed.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#app_hub_service::Google::Cloud::Developerconnect::V1::AppHubService (readonly)



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159

class RuntimeConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the runtime in the InsightsConfig.
  # Whether the runtime is linked to the InsightsConfig.
  module State
    # No state specified.
    STATE_UNSPECIFIED = 0

    # The runtime configuration has been linked to the InsightsConfig.
    LINKED = 1

    # The runtime configuration has been unlinked to the InsightsConfig.
    UNLINKED = 2
  end
end

#app_hub_workload::Google::Cloud::Developerconnect::V1::AppHubWorkload (readonly)



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159

class RuntimeConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the runtime in the InsightsConfig.
  # Whether the runtime is linked to the InsightsConfig.
  module State
    # No state specified.
    STATE_UNSPECIFIED = 0

    # The runtime configuration has been linked to the InsightsConfig.
    LINKED = 1

    # The runtime configuration has been unlinked to the InsightsConfig.
    UNLINKED = 2
  end
end

#gke_workload::Google::Cloud::Developerconnect::V1::GKEWorkload (readonly)



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159

class RuntimeConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the runtime in the InsightsConfig.
  # Whether the runtime is linked to the InsightsConfig.
  module State
    # No state specified.
    STATE_UNSPECIFIED = 0

    # The runtime configuration has been linked to the InsightsConfig.
    LINKED = 1

    # The runtime configuration has been unlinked to the InsightsConfig.
    UNLINKED = 2
  end
end

#google_cloud_run::Google::Cloud::Developerconnect::V1::GoogleCloudRun (readonly)



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159

class RuntimeConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the runtime in the InsightsConfig.
  # Whether the runtime is linked to the InsightsConfig.
  module State
    # No state specified.
    STATE_UNSPECIFIED = 0

    # The runtime configuration has been linked to the InsightsConfig.
    LINKED = 1

    # The runtime configuration has been unlinked to the InsightsConfig.
    UNLINKED = 2
  end
end

#state::Google::Cloud::Developerconnect::V1::RuntimeConfig::State (readonly)



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159

class RuntimeConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the runtime in the InsightsConfig.
  # Whether the runtime is linked to the InsightsConfig.
  module State
    # No state specified.
    STATE_UNSPECIFIED = 0

    # The runtime configuration has been linked to the InsightsConfig.
    LINKED = 1

    # The runtime configuration has been unlinked to the InsightsConfig.
    UNLINKED = 2
  end
end

#uri::String



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'proto_docs/google/cloud/developerconnect/v1/insights_config.rb', line 159

class RuntimeConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the runtime in the InsightsConfig.
  # Whether the runtime is linked to the InsightsConfig.
  module State
    # No state specified.
    STATE_UNSPECIFIED = 0

    # The runtime configuration has been linked to the InsightsConfig.
    LINKED = 1

    # The runtime configuration has been unlinked to the InsightsConfig.
    UNLINKED = 2
  end
end